sequencetools.partition_sequence_once_by_weights_exactly_with_overhang
======================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_once_by_weights_exactly_with_overhang
